@@ -39,7 +39,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class EntryGroup : public TQObject, public EntryVec {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
