@@ -28,17 +28,17 @@
 #include "tellico_utils.h"
 #include "stringset.h"
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <kpushbutton.h>
 #include <kstatusbar.h>
-#include <khtmlview.h>
+#include <tdehtmlview.h>
 #include <kprogress.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdialogbase.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <kaccelmanager.h>
+#include <tdeaccelmanager.h>
 #include <ktextedit.h>
 
 #include <tqlayout.h>
@@ -122,7 +122,7 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   int maxWidth = m_searchButton->sizeHint().width();
   int maxHeight = m_searchButton->sizeHint().height();
   m_searchButton->setGuiItem(KGuiItem(i18n(FETCH_STRING_SEARCH),
-                                      SmallIconSet(TQString::fromLatin1("find"))));
+                                      SmallIconSet(TQString::fromLatin1("edit-find"))));
   maxWidth = TQMAX(maxWidth, m_searchButton->sizeHint().width());
   maxHeight = TQMAX(maxHeight, m_searchButton->sizeHint().height());
   m_searchButton->setMinimumWidth(maxWidth);
@@ -195,7 +195,7 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   connect(m_addButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotAddEntry()));
   TQWhatsThis::add(m_addButton, i18n("Add the selected entry to the current collection"));
 
-  m_moreButton = new KPushButton(KGuiItem(i18n("Get More Results"), SmallIconSet(TQString::fromLatin1("find"))), box3);
+  m_moreButton = new KPushButton(KGuiItem(i18n("Get More Results"), SmallIconSet(TQString::fromLatin1("edit-find"))), box3);
   m_moreButton->setEnabled(false);
   connect(m_moreButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotMoreClicked()));
   TQWhatsThis::add(m_moreButton, i18n("Fetch more results from the current data source"));
@@ -227,7 +227,7 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
 
   resize(configDialogSize(TQString::fromLatin1("Fetch Dialog Options")));
 
-  KConfigGroup config(kapp->config(), "Fetch Dialog Options");
+  TDEConfigGroup config(kapp->config(), "Fetch Dialog Options");
   TQValueList<int> splitList = config.readIntListEntry("Splitter Sizes");
   if(!splitList.empty()) {
     split->setSizes(splitList);
@@ -243,7 +243,7 @@ FetchDialog::FetchDialog(TQWidget* parent_, const char* name_)
   // make sure to delete results afterwards
   m_results.setAutoDelete(true);
 
-  KAcceleratorManager::manage(this);
+  TDEAcceleratorManager::manage(this);
   // initialize combos
   TQTimer::singleShot(0, this, TQT_SLOT(slotInit()));
 
@@ -287,7 +287,7 @@ FetchDialog::~FetchDialog() {
 
   saveDialogSize(TQString::fromLatin1("Fetch Dialog Options"));
 
-  KConfigGroup config(kapp->config(), "Fetch Dialog Options");
+  TDEConfigGroup config(kapp->config(), "Fetch Dialog Options");
   config.writeEntry("Splitter Sizes", static_cast<TQSplitter*>(m_listView->parentWidget())->sizes());
   config.writeEntry("Search Key", m_keyCombo->currentData().toInt());
   config.writeEntry("Search Source", m_sourceCombo->currentText());
@@ -363,7 +363,7 @@ void FetchDialog::slotFetchDone(bool checkISBN /* = true */) {
 //  myDebug() << "FetchDialog::slotFetchDone()" << endl;
   m_started = false;
   m_searchButton->setGuiItem(KGuiItem(i18n(FETCH_STRING_SEARCH),
-                                      SmallIconSet(TQString::fromLatin1("find"))));
+                                      SmallIconSet(TQString::fromLatin1("edit-find"))));
   stopProgress();
   if(m_resultCount == 0) {
     slotStatus(i18n("The search returned no items."));
@@ -407,9 +407,9 @@ void FetchDialog::slotFetchDone(bool checkISBN /* = true */) {
       TQVBoxLayout* lay = new TQVBoxLayout(box, KDialog::marginHint(), KDialog::spacingHint()*2);
       TQHBoxLayout* lay2 = new TQHBoxLayout(lay);
       TQLabel* lab = new TQLabel(box);
-      lab->setPixmap(KGlobal::iconLoader()->loadIcon(TQString::fromLatin1("messagebox_info"),
-                                                     KIcon::NoGroup,
-                                                     KIcon::SizeMedium));
+      lab->setPixmap(TDEGlobal::iconLoader()->loadIcon(TQString::fromLatin1("messagebox_info"),
+                                                     TDEIcon::NoGroup,
+                                                     TDEIcon::SizeMedium));
       lay2->addWidget(lab);
       TQString s = i18n("No results were found for the following ISBN values:");
       lay2->addWidget(new TQLabel(s, box), 10);
@@ -530,7 +530,7 @@ void FetchDialog::slotInit() {
     Kernel::self()->sorry(i18n("No Internet sources are available for your current collection type."), this);
   }
 
-  KConfigGroup config(kapp->config(), "Fetch Dialog Options");
+  TDEConfigGroup config(kapp->config(), "Fetch Dialog Options");
   int key = config.readNumEntry("Search Key", Fetch::FetchFirst);
   // only change key if valid
   if(key > Fetch::FetchFirst) {
@@ -591,6 +591,10 @@ void FetchDialog::slotMultipleISBN(bool toggle_) {
     m_valueLineEdit->setText(val);
   }
   m_editISBN->setEnabled(toggle_);
+  if(toggle_) {
+    // if we're editing multiple values, it makes sense to popup the dialog now
+    slotEditMultipleISBN();
+  }
 }
 
 void FetchDialog::slotEditMultipleISBN() {
@@ -603,7 +607,7 @@ void FetchDialog::slotEditMultipleISBN() {
   m_isbnTextEdit = new KTextEdit(box, "isbn text edit");
   m_isbnTextEdit->setText(m_isbnList.join(TQChar('\n')));
   TQWhatsThis::add(m_isbnTextEdit, s);
-  KPushButton* fromFileBtn = new KPushButton(SmallIconSet(TQString::fromLatin1("fileopen")),
+  KPushButton* fromFileBtn = new KPushButton(SmallIconSet(TQString::fromLatin1("document-open")),
                                              i18n("&Load From File..."), box);
   TQWhatsThis::add(fromFileBtn, i18n("<qt>Load the list from a text file.</qt>"));
   connect(fromFileBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotLoadISBNList()));
@@ -656,7 +660,7 @@ void FetchDialog::slotUPC2ISBN() {
 }
 
 bool FetchDialog::eventFilter(TQObject* obj_, TQEvent* ev_) {
-  if(TQT_BASE_OBJECT(obj_) == TQT_BASE_OBJECT(m_listView->viewport()) && ev_->type() == TQEvent::Resize) {
+  if(obj_ == m_listView->viewport() && ev_->type() == TQEvent::Resize) {
     adjustColumnWidth();
   }
   return false;
