@@ -36,7 +36,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class FieldWidget : public TQWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
