@@ -32,7 +32,7 @@ void TabControl::setFocusToFirstChild() {
   if(!page) {
     return;
   }
-  TQObjectList* list = page->queryList(TQWIDGET_OBJECT_NAME_STRING);
+  TQObjectList* list = page->queryList("TQWidget");
   for(TQObjectListIt it(*list); it.current(); ++it) {
     TQWidget* w = TQT_TQWIDGET(it.current());
     if(w->isFocusEnabled()) {
