@@ -540,7 +540,7 @@ void Dialog::slotPreviewResult(TDEIO::Job* job_) {
 
   if(!pix.isNull()) {
     if(pix.width() > 64 || pix.height() > 64) {
-      pix.convertFromImage(pix.convertToImage().smoothScale(64, 64, TQ_ScaleMin));
+      pix.convertFromImage(pix.convertToImage().smoothScale(64, 64, TQImage::ScaleMin));
     }
     // only set label if it's still current
     if(m_listView->selectedItem() == m_lastPreviewItem) {
