@@ -15,9 +15,9 @@
  ***************************************************************************/
 
 // force to use QT with STL
-#if defined(QT_NO_STL)
-# define DISABLE_QT_NO_STL
-# undef QT_NO_STL
+#if defined(TQT_NO_STL)
+# define DISABLE_TQT_NO_STL
+# undef TQT_NO_STL
 #endif
 
 #include "rtf2html.h"
@@ -535,8 +535,8 @@ TQString RTF2HTML::toHTML() const {
    return html;
 }
 
-// restore QT_NO_STL
-#if defined(DISABLE_QT_NO_STL)
-# undef DISABLE_QT_NO_STL
-# define QT_NO_STL
+// restore TQT_NO_STL
+#if defined(DISABLE_TQT_NO_STL)
+# undef DISABLE_TQT_NO_STL
+# define TQT_NO_STL
 #endif
