@@ -166,7 +166,7 @@ TQString ONIXExporter::text() {
 }
 
 TQWidget* ONIXExporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
-  if(m_widget && TQT_BASE_OBJECT(m_widget->parent()) == TQT_BASE_OBJECT(parent_)) {
+  if(m_widget && m_widget->parent() == parent_) {
     return m_widget;
   }
 
