@@ -64,7 +64,7 @@ bool XSLTExporter::exec() {
 }
 
 TQWidget* XSLTExporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
-  if(m_widget && TQT_BASE_OBJECT(m_widget->parent()) == TQT_BASE_OBJECT(parent_)) {
+  if(m_widget && m_widget->parent() == parent_) {
     return m_widget;
   }
 
